package org.seoanej.imindanger;

import android.app.Activity;
import android.app.ListActivity;
import android.content.Intent;
import android.database.Cursor;
import android.net.Uri;
import android.os.Bundle;
import android.provider.ContactsContract;
import android.util.Log;
import android.view.Menu;
import android.view.MenuItem;
import android.view.View;
import android.widget.ListView;
import android.widget.Toast;

public class ListaContactos extends ListActivity {

	private IAlmacenContactos almacen;
	private static final int PICK_CONTACT = 1;

	@Override
	public void onCreate(Bundle savedInstanceState) {
		super.onCreate(savedInstanceState);

		almacen = new AlmacenContactosSQLite(this);
		setContentView(R.layout.contactos);
		setListAdapter(new MiAdaptador(this, almacen.listaContactos()));
	}

	@Override
	public void onResume() {
		super.onResume();
		almacen = new AlmacenContactosSQLite(this);
		setContentView(R.layout.contactos);
		setListAdapter(new MiAdaptador(this, almacen.listaContactos()));
		Log.d("Listar contactos", "ok");
	}

	@Override
	protected void onListItemClick(ListView listView, View view, int position,
			long id) {
		super.onListItemClick(listView, view, position, id);
		Contacto c = (Contacto) getListAdapter().getItem(position);
		lanzarEditarContacto(c.getId());
	}

	// Metodos de la interfaz
	@Override
	public boolean onCreateOptionsMenu(Menu menu) {
		getMenuInflater().inflate(R.menu.contactos, menu);
		return true;
	}

	@Override
	public boolean onOptionsItemSelected(MenuItem item) {
		switch (item.getItemId()) {
		case R.id.nuevo_contacto:
			lanzarNuevoContacto();
			break;

		case R.id.importar_contacto:
			lanzarImportarContacto();
			break;
		}

		return true; // true -> consumimos el item, no se propaga
	}

	// Lanzar actividades
	public void lanzarNuevoContacto() {
		Intent i = new Intent(this, NuevoContacto.class);
		startActivity(i);
	}

	public void lanzarImportarContacto() {
		Intent intent = new Intent(Intent.ACTION_PICK,
				ContactsContract.Contacts.CONTENT_URI);
		startActivityForResult(intent, PICK_CONTACT);
	}
	
	public void lanzarEditarContacto(int id_contacto) {
		Intent i = new Intent(this, EditarContacto.class);
		i.putExtra("id", id_contacto);
		startActivity(i);
	}

	// code
	@Override
	public void onActivityResult(int reqCode, int resultCode, Intent data) {
		super.onActivityResult(reqCode, resultCode, data);

		switch (reqCode) {
		case (PICK_CONTACT):
			if (resultCode == Activity.RESULT_OK) {

				String cNumber = "";
				String cName = "";

				Uri contactData = data.getData();
				@SuppressWarnings("deprecation")
				Cursor c = managedQuery(contactData, null, null, null, null);
				if (c.moveToFirst()) {

					String id = c
							.getString(c
									.getColumnIndexOrThrow(ContactsContract.Contacts._ID));

					String hasPhone = c
							.getString(c
									.getColumnIndex(ContactsContract.Contacts.HAS_PHONE_NUMBER));

					if (hasPhone.equalsIgnoreCase("1")) {
						Cursor phones = getContentResolver()
								.query(ContactsContract.CommonDataKinds.Phone.CONTENT_URI,
										null,
										ContactsContract.CommonDataKinds.Phone.CONTACT_ID
												+ " = " + id, null, null);
						phones.moveToFirst();
						cNumber = phones.getString(phones
								.getColumnIndex("data1"));
					}
					cName = c
							.getString(c
									.getColumnIndex(ContactsContract.Contacts.DISPLAY_NAME));

					// Guardar contacto en la base de datos
					almacen.guardarContacto(cName, cNumber);
				}

			}
			break;
		}
	}
}
