package org.seoanej.imindanger;

import java.io.IOException;
import java.util.ArrayList;
import java.util.List;
import java.util.Locale;
import java.util.Vector;

import android.app.Activity;
import android.content.Intent;
import android.location.Address;
import android.location.Criteria;
import android.location.Geocoder;
import android.location.Location;
import android.location.LocationListener;
import android.location.LocationManager;
import android.os.Bundle;
import android.telephony.SmsManager;
import android.util.Log;
import android.view.Menu;
import android.view.MenuItem;
import android.view.View;
import android.widget.Button;
import android.widget.Toast;

public class MainActivity extends Activity implements LocationListener {

	// Localizacion
	private LocationManager manejador;
	private String proveedor;
	private static final long TIEMPO_MIN = 10 * 1000; // 10 segundos
	private static final long DISTANCIA_MIN = 5; // 5 metros

	// Envio del mensaje
	Button sendBtn;
	private IAlmacenContactos almacen;

	// Mtodos del Ciclo de vida
	@Override
	protected void onCreate(Bundle savedInstanceState) {
		super.onCreate(savedInstanceState);
		setContentView(R.layout.activity_main);

		// Localizacion
		manejador = (LocationManager) getSystemService(LOCATION_SERVICE);

		// Proveedor
		Criteria criterio = new Criteria();
		criterio.setCostAllowed(false);
		criterio.setAltitudeRequired(false);
		criterio.setAccuracy(Criteria.ACCURACY_FINE);
		proveedor = manejador.getBestProvider(criterio, true);

		// Enviar SMS
		sendBtn = (Button) findViewById(R.id.btnSendSMS);
		sendBtn.setOnClickListener(new View.OnClickListener() {
			public void onClick(View view) {
				sendSMSMessages();
			}
		});
	}

	@Override
	protected void onResume() {
		super.onResume();
		manejador.requestLocationUpdates(proveedor, TIEMPO_MIN, DISTANCIA_MIN,
				(LocationListener) this);
	}

	@Override
	protected void onPause() {
		super.onPause();
		//manejador.removeUpdates(this);
	}

	// Mtodos de LocationListener
	@Override
	public void onLocationChanged(Location location) {

		if (location == null) {
			Toast.makeText(this, "Buscando posicin, espere porfavor ...",
					Toast.LENGTH_LONG).show();
		} else {
			Toast.makeText(getApplicationContext(),
					"Cambio de estado: " + proveedor, Toast.LENGTH_LONG).show();
		}
	}

	@Override
	public void onStatusChanged(String provider, int status, Bundle extras) {
		Toast.makeText(getApplicationContext(), "Status changed: " + provider,
				Toast.LENGTH_LONG).show();
	}

	@Override
	public void onProviderEnabled(String provider) {
		Toast.makeText(getApplicationContext(),
				"Provider enabled: " + provider, Toast.LENGTH_LONG).show();
	}

	@Override
	public void onProviderDisabled(String provider) {
		Toast.makeText(getApplicationContext(),
				"Provider disabled: " + provider, Toast.LENGTH_LONG).show();
	}

	// Metodos auxiliares

	protected void sendSMSMessages() {
		almacen = new AlmacenContactosSQLite(this);
		Vector<Contacto> listaContactos = almacen.listaContactos();
		String message = "ESTOY EN PELIGRO! Intenta localizarme.";
		String geoposition = "";
		String LatLong = "";

		Log.i("envio de los SMS", "");

		// Encontrar direccion por las coordenadas
		Geocoder gcd = new Geocoder(this, Locale.getDefault());
		List<Address> addresses;
		try {
			// get coordenadas
			double lat = manejador.getLastKnownLocation(proveedor)
					.getLatitude();
			double lon = manejador.getLastKnownLocation(proveedor)
					.getLongitude();

			LatLong = "[" + lat + " ," + lon + "]";

			// get pays, ciudad, calle
			addresses = gcd.getFromLocation(lat, lon, 1);
			if (addresses.size() > 0) // pais,ciudad,cp,calle
				geoposition = addresses.get(0).getCountryName() + " "
						+ addresses.get(0).getLocality() + " "
						+ addresses.get(0).getPostalCode() + " "
						+ addresses.get(0).getThoroughfare() + " ";
		} catch (IOException e1) {
			e1.printStackTrace();

		} catch (NullPointerException npe) {
			Toast.makeText(
					this,
					"No existe ninguna localizacin registrada, el mensaje se enviar sin la localizacin actual",
					Toast.LENGTH_LONG).show();
					geoposition="El dispositivo no tena registrada ninguna localizacin.";
		}

		// envio de los mensajes a todos los numeros guardados
		if(listaContactos.isEmpty()){
			Toast.makeText(
					getApplicationContext(),
					"No hay contactos de alerta registrados.",
					Toast.LENGTH_LONG).show();			
		} else {
			for (Contacto contact : listaContactos) {
				try {
					SmsManager smsManager = SmsManager.getDefault();
					//MENSAJE 1: direccin y coordenadas
					smsManager.sendTextMessage(contact.getTelefono(), null,
							(geoposition + " " + LatLong), null, null);
					//MENSAJE 2: texto explicativo
					smsManager.sendTextMessage(contact.getTelefono(), null,
							(contact.getNombre() + " " + message), null, null);
					Toast.makeText(
							getApplicationContext(),
							(contact.getNombre() + ", " + message + " "
									+ geoposition + " " + LatLong),
							Toast.LENGTH_LONG).show();
				// envioCorrecto = true;
				} catch (Exception e) {
					Toast.makeText(
							getApplicationContext(),
							"Error en el envo del sms, vuelva a intentarlo porfavor.",
							Toast.LENGTH_LONG).show();
					e.printStackTrace();
				}
			}	
		}
	}

	// Metodos de la interfaz
	@Override
	public boolean onCreateOptionsMenu(Menu menu) {
		getMenuInflater().inflate(R.menu.menu, menu);
		return true;
	}

	@Override
	public boolean onOptionsItemSelected(MenuItem item) {
		switch (item.getItemId()) {
		case R.id.acercaDe:
			lanzarAboutUs(null);
			break;

		case R.id.config:
			lanzarListaContactos(null);
			break;
			
		case R.id.ayuda:
			lanzarAyuda(null);
			break;
		}

		return true; // true -> consumimos el item, no se propaga
	}

	//Actividades del menu
	public void lanzarAboutUs(View view) {
		Intent i = new Intent(this, AboutUs.class);
		startActivity(i);
	}

	public void lanzarListaContactos(View view) {
		Intent i = new Intent(this, ListaContactos.class);
		startActivity(i);
	}
	
	// Lanzar actividades
	public void lanzarAyuda(View view) {
		Intent i = new Intent(this, Ayuda.class);
		startActivity(i);
	}

}
